summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@collabora.com>2017-07-28 13:58:29 +0200
committerJan Holesovsky <kendy@collabora.com>2017-07-28 14:38:35 +0200
commit74c8d4a8128056a35fb2c67b7f663b259665e193 (patch)
treefc87d0a1eb8617290671c5db588708ec1cf0e76d
parentc15c93467b62618bc7a977d137d25a491a26158b (diff)
sw htmlexport: Consistent naming in the test.
Change-Id: I608b818063f3ac66c6b36f9f8d221a54bfe1be24
-rw-r--r--sw/qa/extras/htmlexport/htmlexport.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/qa/extras/htmlexport/htmlexport.cxx b/sw/qa/extras/htmlexport/htmlexport.cxx
index c28d1ec4b997..63435cee780a 100644
--- a/sw/qa/extras/htmlexport/htmlexport.cxx
+++ b/sw/qa/extras/htmlexport/htmlexport.cxx
@@ -44,7 +44,7 @@ private:
virtual std::unique_ptr<Resetter> preTest(const char* filename) override
{
- if (getTestName().indexOf("SkipImage") != -1)
+ if (getTestName().indexOf("SkipImages") != -1)
setFilterOptions("SkipImages");
else
setFilterOptions("");
@@ -138,7 +138,7 @@ DECLARE_HTMLEXPORT_TEST(testExportOfImages, "textAndImage.docx")
assertXPath(pDoc, "/html/body/p/img", 1);
}
-DECLARE_HTMLEXPORT_TEST(testExportOfImagesWithSkipImageEnabled, "textAndImage.docx")
+DECLARE_HTMLEXPORT_TEST(testExportOfImagesWithSkipImagesEnabled, "textAndImage.docx")
{
htmlDocPtr pDoc = parseHtml(maTempFile);
CPPUNIT_ASSERT(pDoc);
@@ -147,7 +147,7 @@ DECLARE_HTMLEXPORT_TEST(testExportOfImagesWithSkipImageEnabled, "textAndImage.do
assertXPath(pDoc, "/html/body/p/img", 0);
}
-DECLARE_HTMLEXPORT_TEST(testSkipImageEmbedded, "skipimage-embedded.doc")
+DECLARE_HTMLEXPORT_TEST(testSkipImagesEmbedded, "skipimage-embedded.doc")
{
// Embedded spreadsheet was exported as image, so content was lost. Make
// sure it's exported as HTML instead.
@@ -162,9 +162,9 @@ DECLARE_HTMLEXPORT_TEST(testSkipImageEmbedded, "skipimage-embedded.doc")
assertXPath(pDoc, "//span/table", 1);
}
-DECLARE_HTMLEXPORT_TEST(testSkipImageEmbeddedDocument, "skipimage-embedded-document.docx")
+DECLARE_HTMLEXPORT_TEST(testSkipImagesEmbeddedDocument, "skipimage-embedded-document.docx")
{
// Similar to testSkipImageEmbedded, but with an embedded Writer object,
// not a Calc one, and this time OOXML, not WW8.
htmlDocPtr pDoc = parseHtml(maTempFile);
CPPUNIT_ASSERT(pDoc);
@@ -162,9 +162,9 @@ DECLARE_HTMLEXPORT_TEST(testSkipImageEmbedded, "skipimage-embedded.doc")
{
- // Similar to testSkipImageEmbedded, but with an embedded Writer object,
+ // Similar to testSkipImagesEmbedded, but with an embedded Writer object,
// not a Calc one, and this time OOXML, not WW8.
htmlDocPtr pDoc = parseHtml(maTempFile);